@@ -323,7 +323,7 @@ blog_blogger_parse_getevents_request (DrivelClient *dc, DrivelRequest *dr)
 		if (postid && content)
 		{
 			journal_edit_entry (dc, postid, content, NULL, NULL, NULL, NULL,
-					NULL, NULL, NULL, NULL, NULL, NULL);
+					NULL, NULL, NULL, NULL, NULL, NULL, NULL);
 		}
 	}
 	else
@@ -351,7 +351,7 @@ blog_blogger_parse_getevents_request (DrivelClient *dc, DrivelRequest *dr)
 				entry->content = g_strdup (content);
 				entry->userid = g_strdup (userid);
 				strptime (date, "%Y%m%dT%H:%M:%S", &entry->date_posted);
-				g_array_append_val (dc->recent_entries, entry);
+				g_ptr_array_add (dc->recent_entries, entry);
 			}
 		}
 		
