@@ -484,7 +484,7 @@ DrivelRequest*
 blog_lj_build_postevent_request (const gchar *username, const gchar *uri,
 		const gchar *event, const gchar *music, const gchar *mood,
 		gint moodid, const gchar *subject, const gchar *security, gint mask,
-		const gchar *picture, gint year, gint month, gint day, gint hour,
+		const gchar *picture, const gchar *tags, gint year, gint month, gint day, gint hour,
 		gint minute, gint nocomments, gint preformatted, 
 		const DrivelJournal *dj, gint backdate)
 {
@@ -511,6 +511,7 @@ blog_lj_build_postevent_request (const gchar *username, const gchar *uri,
 			curl_escape ("prop_current_music", 0), curl_escape (music, 0),
 			curl_escape ("prop_current_mood", 0), curl_escape (mood, 0),
 			curl_escape ("prop_picture_keyword", 0), curl_escape (picture, 0),
+			curl_escape ("prop_taglist", 0), curl_escape (tags, 0),
 			NULL);
 	
 	
@@ -567,8 +568,8 @@ DrivelRequest*
 blog_lj_build_editevent_request (const gchar *username, const gchar *uri,
 		const gchar *itemid, const gchar *event, const gchar *music, 
 		const gchar *mood, gint moodid, const gchar *subject, 
-		const gchar *security, gint mask, const gchar *picture, gint year, 
-		gint month, gint day, gboolean newdate, gint nocomments, 
+		const gchar *security, gint mask, const gchar *picture, const gchar *tags,
+		gint year, gint month, gint day, gboolean newdate, gint nocomments, 
 		gint preformatted, const DrivelJournal *dj)
 {
 	DrivelRequest *dr;
@@ -595,6 +596,7 @@ blog_lj_build_editevent_request (const gchar *username, const gchar *uri,
 			curl_escape ("prop_current_music", 0), curl_escape (music, 0),
 			curl_escape ("prop_current_mood", 0), curl_escape (mood, 0),
 			curl_escape ("prop_picture_keyword", 0), curl_escape (picture, 0),
+			curl_escape ("prop_taglist", 0), curl_escape (tags, 0),
 			NULL);
 	
 	
@@ -749,7 +751,7 @@ blog_lj_parse_getevents_request (DrivelClient *dc, DrivelRequest *dr)
 {
 	const gchar *mesg;
 	gchar **itemid, **new_event, key [32];
-	gchar **old_event, **security, **allowmask, **subject;
+	gchar **old_event, **security, **allowmask, **subject, **tags;
 	gchar **eventtime, **comments = NULL, **autoformat = NULL;
 	gchar **mood = NULL, **music = NULL, **picture = NULL;
 	gint prop_count, events_count, i, j;
@@ -774,6 +776,7 @@ blog_lj_parse_getevents_request (DrivelClient *dc, DrivelRequest *dr)
 	security = g_new (gchar *, events_count + 1);
 	allowmask = g_new (gchar *, events_count + 1);
 	subject = g_new (gchar *, events_count + 1);
+	tags = g_new (gchar *, events_count + 1);
 	eventtime = g_new (gchar *, events_count + 1);
 	picture = g_new (gchar *, events_count + 1);
 	mood = g_new (gchar *, events_count + 1);
@@ -789,6 +792,7 @@ blog_lj_parse_getevents_request (DrivelClient *dc, DrivelRequest *dr)
 		security [i] = NULL;
 		allowmask [i] = NULL;
 		subject [i] = NULL;
+		tags [i] = NULL;
 		eventtime [i] = NULL;
 		picture [i] = NULL;
 		mood [i] = NULL;
@@ -846,6 +850,8 @@ blog_lj_parse_getevents_request (DrivelClient *dc, DrivelRequest *dr)
 				comments [i] = g_strdup (drivel_request_value_lookup (dr, key));
 			else if (!strcmp (mesg, "opt_preformatted"))
 				autoformat [i] = g_strdup (drivel_request_value_lookup (dr, key));
+			else if (!strcmp (mesg, "taglist"))
+				tags [i] = g_strdup (drivel_request_value_lookup (dr, key));
 		}
 	}
 	
@@ -868,42 +874,49 @@ blog_lj_parse_getevents_request (DrivelClient *dc, DrivelRequest *dr)
 				prop = journal_prop_new ();
 				prop->name = g_strdup ("picture");
 				prop->value = g_strdup (picture[i]);
-				g_array_append_val (entry->properties, prop);
+				g_ptr_array_add (entry->properties, prop);
 			}
 			if (music[i])
 			{
 				prop = journal_prop_new ();
 				prop->name = g_strdup ("music");
 				prop->value = g_strdup (music[i]);
-				g_array_append_val (entry->properties, prop);
+				g_ptr_array_add (entry->properties, prop);
 			}
 			if (mood[i])
 			{
 				prop = journal_prop_new ();
 				prop->name = g_strdup ("mood");
 				prop->value = g_strdup (mood[i]);
-				g_array_append_val (entry->properties, prop);
+				g_ptr_array_add (entry->properties, prop);
 			}
 			if (comments[i])
 			{
 				prop = journal_prop_new ();
 				prop->name = g_strdup ("comments");
 				prop->value = g_strdup (comments[i]);
-				g_array_append_val (entry->properties, prop);
+				g_ptr_array_add (entry->properties, prop);
 			}
 			if (autoformat[i])
 			{
 				prop = journal_prop_new ();
 				prop->name = g_strdup ("autoformat");
 				prop->value = g_strdup (autoformat[i]);
-				g_array_append_val (entry->properties, prop);
+				g_ptr_array_add (entry->properties, prop);
+			}
+			if (tags[i])
+			{
+				prop = journal_prop_new ();
+				prop->name = g_strdup ("taglist");
+				prop->value = g_strdup (tags[i]);
+				g_ptr_array_add (entry->properties, prop);
 			}
 			prop = journal_prop_new ();
 			prop->name = g_strdup ("eventtime");
 			prop->value = g_strdup (eventtime[i]);
-			g_array_append_val (entry->properties, prop);
+			g_ptr_array_add (entry->properties, prop);
 			
-			g_array_append_val (dc->recent_entries, entry);
+			g_ptr_array_add (dc->recent_entries, entry);
 		}
 		
 		journal_refresh_recent_entries (dc);
@@ -912,7 +925,7 @@ blog_lj_parse_getevents_request (DrivelClient *dc, DrivelRequest *dr)
 	{	
 		journal_edit_entry (dc, itemid [0], new_event [0], security [0], 
 				allowmask [0], subject [0],	mood [0], music [0], picture [0], 
-				eventtime [0], comments [0], autoformat [0], NULL);
+				eventtime [0], comments [0], autoformat [0], NULL, tags [0]);
 	}
 	else
 		update_history_list (dc, itemid, new_event, eventtime, events_count);
@@ -929,6 +942,7 @@ blog_lj_parse_getevents_request (DrivelClient *dc, DrivelRequest *dr)
 	g_strfreev (music);
 	g_strfreev (comments);
 	g_strfreev (autoformat);
+	g_strfreev (tags);
 	
 	return;
 }
