@@ -558,7 +558,7 @@ blog_mt_parse_getevents_request (DrivelClient *dc, DrivelRequest *dr)
 			DrivelRequest *dr;
 			
 			journal_edit_entry (dc, postid, content, NULL, NULL, title, NULL,
-					NULL, NULL, NULL, NULL, NULL, NULL);
+					NULL, NULL, NULL, NULL, NULL, NULL, NULL);
 			
 			dr = blog_mt_build_getpostcategories_request (dc->user->username,
 					dc->user->password, dc->user->server, postid);
@@ -596,7 +596,7 @@ blog_mt_parse_getevents_request (DrivelClient *dc, DrivelRequest *dr)
 				if (title)
 					entry->subject = g_strdup (title);
 				strptime (date, "%Y%m%dT%H:%M:%S", &entry->date_posted);
-				g_array_append_val (dc->recent_entries, entry);
+				g_ptr_array_add (dc->recent_entries, entry);
 			}
 		}
 		
