@@ -81,21 +81,19 @@ grey_button_cb (GtkWidget *entry, gpointer data)
 static DrivelButtonVAList *
 dialog_grey_button_on_invalid (GtkWidget *button, GtkWidget *entry, ...)
 {
-	va_list *args;
+	va_list args;
 	gint signal;
 	GtkWidget *w;
 	DrivelButtonVAList *bval;
 	
-	args = g_new0 (va_list, 1);
-	
-	va_start (*args, entry);
+	va_start (args, entry);
 
 	bval = g_new0 (DrivelButtonVAList, 1);
 	bval->button = button;
 	bval->entries = NULL;
 	bval->signals = NULL;
 	
-	for (w = entry; w; w = va_arg (*args, GtkWidget *))
+	for (w = entry; w; w = va_arg (args, GtkWidget *))
 	{
 		bval->entries = g_slist_prepend (bval->entries, w);
 		signal = g_signal_connect (G_OBJECT (w), "changed",
@@ -104,7 +102,7 @@ dialog_grey_button_on_invalid (GtkWidget *button, GtkWidget *entry, ...)
 				GINT_TO_POINTER (signal));
 	}
 	
-	va_end (*args);
+	va_end (args);
 	
 	return bval;
 }
