@@ -162,7 +162,7 @@ struct _DrivelJournalEntry
 	gchar *userid; /* feed_uri for atom, userid for others */
 	gchar *issued;
 	gchar *link;
-	GArray *properties; /* lj meta data */
+	GPtrArray *properties; /* lj meta data */
 };
 
 struct _DrivelJournalProp
@@ -218,6 +218,7 @@ struct _DrivelClient
 	GtkWidget *journal_backdate;
 	GtkWidget *journal_date;
 	GtkWidget *journal_category;
+	GtkWidget *journal_tags;
 	GtkTextBuffer *buffer;
 	GtkWidget *journal_post;
 	GtkWidget *edit_delete;
@@ -333,7 +334,7 @@ struct _DrivelClient
 	gchar *draft_filename;
 	DrivelTime time;
 	DrivelIDs id;
-	GArray *recent_entries;
+	GPtrArray *recent_entries;
 };
 
 void
