@@ -200,7 +200,7 @@ build_journal_type_combo (GtkListStore **type_store)
 	gtk_list_store_set (*type_store, &iter,
 			TYPE_ICON, pixbuf_small,
 			TYPE_NAME, "Blogger 1.0",
-			TYPE_SERVER, "http://plant.blogger.com/api/RPC2",
+			TYPE_SERVER, "http://www.blogger.com/api/RPC2",
 			TYPE_API, BLOG_API_BLOGGER,
 			-1);
 	
