@@ -170,8 +170,7 @@ clear_recent_entries (GArray *recent)
 	{
 		DrivelJournalEntry *entry;
 		
-		entry = g_array_index (recent, DrivelJournalEntry*, 0);
-		g_array_remove_index (recent, 0);
+		entry = g_ptr_array_remove_index (recent, 0);
 		journal_entry_free (entry);
 	}
 	
@@ -885,7 +884,7 @@ drivel_init (DrivelClient *dc)
 			GTK_TREE_MODEL_FILTER (dc->category_store_filtered),
 			is_category_visible, dc, NULL);
 	dc->draft_filename = NULL;
-	dc->recent_entries = g_array_new (FALSE, TRUE, sizeof (DrivelJournalEntry *));
+	dc->recent_entries = g_ptr_array_new ();
 	
 	drivel_fill_journal_null (dc);
 	
