@@ -62,14 +62,25 @@ static size_t
 write_cb (void *ptr, size_t size, size_t nmemb, void *data)
 {
 	gint realsize = size * nmemb;
+	gint bufsize = realsize;
 	DrivelRequestData *memory = data;
 
-	memory->data = (gchar *) g_realloc (memory->data, memory->len + realsize + 1);
-
-	memcpy (&(memory->data [memory->len]), ptr, realsize);
-	memory->len += realsize;
-	memory->data [memory->len] = '\0';
+	if (memory->len == 0)
+	{
+		while(bufsize > 0 && (((gchar*)ptr)[0]=='\n' || ((gchar*)ptr)[0]==' ' || ((gchar*)ptr)[0] == '\t'))
+		{
+			ptr++;
+			bufsize--;
+		}
+	}
+	if (bufsize > 0)
+	{
+		memory->data = (gchar *) g_realloc (memory->data, memory->len + bufsize + 1);
 
+		memcpy (&(memory->data [memory->len]), ptr, bufsize);
+		memory->len += bufsize;
+		memory->data [memory->len] = '\0';
+	}
 	return realsize;
 }
 
@@ -138,7 +149,7 @@ parse_to_hash_table (DrivelClient *dc, DrivelRequest *dr, const gchar *string, g
 	
 	while (offset < len)
 	{
-		key = get_line (string + offset, &line_offset);
+		key = get_line (string + offset, (gint *)&line_offset);
 		offset += strlen (key) + line_offset;
 		if (line_offset > 1)
 		{
@@ -147,7 +158,7 @@ parse_to_hash_table (DrivelClient *dc, DrivelRequest *dr, const gchar *string, g
 			continue;
 		}
 
-		value = get_line (string + offset, &line_offset);
+		value = get_line (string + offset, (gint *)&line_offset);
 		offset += strlen (value) + line_offset;
 
 		drivel_request_value_insert (dr, key, value);
@@ -285,8 +296,7 @@ setup_proxies (DrivelClient *dc, CURL *session, gchar **proxy_userpwd, gchar **p
 static gchar*
 get_response_lj (const gchar *pass, const gchar *challenge)
 {
-	gchar *response;
-	guchar *hash;
+	gchar *response, *hash;
 	
 	response = g_strdup_printf ("%s%s", challenge, pass);
 	hash = md5_hash (response);
@@ -315,6 +325,7 @@ get_challenge_lj (DrivelClient *dc, DrivelRequest *dr, const gchar *url,
 	cookie = g_strdup_printf ("ljfastserver=%d", fast_servers);
 	
 	session = curl_easy_init ();
+	curl_easy_setopt (session, CURLOPT_FOLLOWLOCATION, 1);
 	curl_easy_setopt (session, CURLOPT_USERAGENT, USER_AGENT);
 	curl_easy_setopt (session, CURLOPT_WRITEFUNCTION, write_cb);
 	curl_easy_setopt (session, CURLOPT_WRITEDATA, memory);
@@ -405,6 +416,7 @@ perform_post (DrivelClient *dc, DrivelRequest *dr, const gchar *url,
 	debug (request_string);
 	
 	session = curl_easy_init ();
+	curl_easy_setopt (session, CURLOPT_FOLLOWLOCATION, 1);
 	curl_easy_setopt (session, CURLOPT_USERAGENT, USER_AGENT);
 	curl_easy_setopt (session, CURLOPT_WRITEFUNCTION, write_cb);
 	curl_easy_setopt (session, CURLOPT_WRITEDATA, memory);
@@ -420,9 +432,10 @@ perform_post (DrivelClient *dc, DrivelRequest *dr, const gchar *url,
 	curl_code = curl_easy_perform (session);
 	
 	http_code = 0;
-	curl_easy_getinfo (session, CURLINFO_HTTP_CODE, &http_code);
+	if (!curl_code)
+		curl_code = curl_easy_getinfo (session, CURLINFO_HTTP_CODE, &http_code);
 	
-	if (http_code == 200 && curl_code != CURLE_ABORTED_BY_CALLBACK)
+	if (http_code >= 200 && http_code < 300 && curl_code != CURLE_ABORTED_BY_CALLBACK)
 	{
 		debug ("post result:");
 		debug (memory->data);
@@ -437,7 +450,8 @@ perform_post (DrivelClient *dc, DrivelRequest *dr, const gchar *url,
 		else
 		{
 			retval = -1;
-			g_warning ("HTTP/POST request failed (HTTP code %d).", (gint)http_code);
+			g_warning ("HTTP/POST request failed (HTTP code %d: %s).", 
+				   (gint)http_code, curl_easy_strerror (curl_code));
 		}
 	}
 	
@@ -471,6 +485,7 @@ perform_get (DrivelClient *dc, DrivelRequest *dr, const gchar *url,
 	debug (url);
 	
 	session = curl_easy_init ();
+	curl_easy_setopt (session, CURLOPT_FOLLOWLOCATION, 1);
 	curl_easy_setopt (session, CURLOPT_USERAGENT, USER_AGENT);
 	curl_easy_setopt (session, CURLOPT_WRITEFUNCTION, write_cb);
 	curl_easy_setopt (session, CURLOPT_WRITEDATA, memory);
@@ -500,7 +515,8 @@ perform_get (DrivelClient *dc, DrivelRequest *dr, const gchar *url,
 	curl_code = curl_easy_perform (session);
 	
 	http_code = 0;
-	curl_easy_getinfo (session, CURLINFO_HTTP_CODE, &http_code);
+	if (!curl_code)
+		curl_code = curl_easy_getinfo (session, CURLINFO_HTTP_CODE, &http_code);
 	
 	if ((http_code == 200 || http_code == 204) && 
 		curl_code != CURLE_ABORTED_BY_CALLBACK)
@@ -521,7 +537,8 @@ perform_get (DrivelClient *dc, DrivelRequest *dr, const gchar *url,
 		else
 		{
 			retval = -1;
-			g_warning ("HTTP/GET request failed (HTTP code %d).", (gint)http_code);
+			g_warning ("HTTP/GET request failed (HTTP code %d: %s).", 
+				   (gint)http_code, curl_easy_strerror (curl_code));
 		}
 	}
 	
@@ -565,6 +582,7 @@ perform_xmlrpc_post (DrivelClient *dc, DrivelRequest *dr, const gchar *url)
 		g_warning ("post_field is NULL");
 	
 	session = curl_easy_init ();
+	curl_easy_setopt (session, CURLOPT_FOLLOWLOCATION, 1);
 	curl_easy_setopt (session, CURLOPT_USERAGENT, USER_AGENT);
 	curl_easy_setopt (session, CURLOPT_URL, url);
 	curl_easy_setopt (session, CURLOPT_POSTFIELDS, post_field);
@@ -580,9 +598,10 @@ perform_xmlrpc_post (DrivelClient *dc, DrivelRequest *dr, const gchar *url)
 	curl_code = curl_easy_perform (session);
 	
 	http_code = 0;
-	curl_easy_getinfo (session, CURLINFO_HTTP_CODE, &http_code);
+	if (!curl_code)
+		curl_code = curl_easy_getinfo (session, CURLINFO_HTTP_CODE, &http_code);
 	
-	if (http_code == 200 && curl_code != CURLE_ABORTED_BY_CALLBACK)
+	if (http_code >= 200 && http_code < 300 && curl_code != CURLE_ABORTED_BY_CALLBACK)
 	{
 		debug ("xmlrpc result:");
 		debug (memory->data);
@@ -601,7 +620,8 @@ perform_xmlrpc_post (DrivelClient *dc, DrivelRequest *dr, const gchar *url)
 		else
 		{
 			retval = -1;
-			g_warning ("HTTP/POST XML-RPC request failed (HTTP code %d).", (gint)http_code);
+			g_warning ("HTTP/POST XML-RPC request failed (HTTP code %d: %s).", 
+				   (gint)http_code, curl_easy_strerror (curl_code));
 		}
 	}
 	
@@ -642,6 +662,7 @@ perform_atom_post (DrivelClient *dc, DrivelRequest *dr,
 		g_warning ("post_field is NULL");
 	
 	session = curl_easy_init ();
+	curl_easy_setopt (session, CURLOPT_FOLLOWLOCATION, 1);
 	curl_easy_setopt (session, CURLOPT_USERAGENT, USER_AGENT);
 	curl_easy_setopt (session, CURLOPT_URL, drivel_request_get_uri (dr));
 	curl_easy_setopt (session, CURLOPT_HTTPHEADER, headers);
@@ -676,9 +697,10 @@ perform_atom_post (DrivelClient *dc, DrivelRequest *dr,
 	curl_code = curl_easy_perform (session);
 	
 	http_code = 0;
-	curl_easy_getinfo (session, CURLINFO_HTTP_CODE, &http_code);
+	if (!curl_code)
+		curl_code = curl_easy_getinfo (session, CURLINFO_HTTP_CODE, &http_code);
 	
-	if (http_code == 200 && curl_code != CURLE_ABORTED_BY_CALLBACK)
+	if (http_code >= 200 && http_code < 300 && curl_code != CURLE_ABORTED_BY_CALLBACK)
 	{
 		debug ("atom result:");
 		debug (wmemory->data);
@@ -699,7 +721,8 @@ perform_atom_post (DrivelClient *dc, DrivelRequest *dr,
 		else
 		{
 			retval = -1;
-			g_warning ("HTTP/POST Atom request failed (HTTP code %d).", (gint)http_code);
+			g_warning ("HTTP/POST Atom request failed (HTTP code %d: %s).",
+				   (gint)http_code, curl_easy_strerror (curl_code));
 		}
 	}
 	
